BuildAuthorizationListResponse class
Response from buildAuthorizationList.
Mirrors the native iOS/Android BuildAuthorizationListResponse shape.
Constructors
- BuildAuthorizationListResponse({required BuildAuthorizationListData data, required BuildAuthorizationListMetadata metadata})
Properties
- data ↔ BuildAuthorizationListData
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata ↔ BuildAuthorizationListMetadata
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → BuildAuthorizationListResponse