DelegationApproveResponse class
Response from approve delegation
Constructors
-
DelegationApproveResponse({List<
DelegationConstructedTransaction?> ? transactions, List<String?> ? encodedTransactions, DelegationApproveMetadata? metadata})
Properties
-
encodedTransactions
↔ List<
String?> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata ↔ DelegationApproveMetadata?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transactions
↔ List<
DelegationConstructedTransaction?> ? -
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → DelegationApproveResponse