Eip7702TransactionResult class

Unsigned EIP-7702 transaction that the consumer should send to the network.

Named with the Result suffix to avoid Swift runtime metadata collisions with PortalSwift.Eip7702Transaction.

authorizationList is sent as a JSON-encoded string to avoid a Pigeon iOS bug where arrays of nested Swift structs trigger swift_getTypeByMangledName failures during __SwiftValue boxing. Use the authorizationList getter on Eip7702TransactionResult (provided in the Dart wrapper) to decode it back to a typed list.

Available extensions

Constructors

Eip7702TransactionResult({String? type, required String from, required String to, String? value, String? data, String? nonce, String? chainId, String? authorizationListJson, String? gasLimit, String? maxFeePerGas, String? maxPriorityFeePerGas})

Properties

authorizationList List<Eip7702AuthorizationListItem>?

Available on Eip7702TransactionResult, provided by the Eip7702TransactionResultExt extension

Decoded authorization list, or null if authorizationListJson is unset/empty, malformed, or doesn't decode to a JSON array. An empty JSON array ("[]") returns an empty list, not null.
no setter
authorizationListJson String?
getter/setter pair
chainId String?
getter/setter pair
data String?
getter/setter pair
from String
getter/setter pair
gasLimit String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxFeePerGas String?
getter/setter pair
maxPriorityFeePerGas String?
getter/setter pair
nonce String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to String
getter/setter pair
type String?
getter/setter pair
value String?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) Eip7702TransactionResult