LifiQuoteRequest class
Request for getting a LiFi quote
Constructors
- LifiQuoteRequest({required String fromChainId, required String fromAmount, required String fromTokenAddress, required String toChainId, required String toTokenAddress, String? fromAddress, String? toAddress, String? fromAmountForGas, LifiRoutesRequestOptions? options})
Properties
- fromAddress ↔ String?
-
getter/setter pair
- fromAmount ↔ String
-
getter/setter pair
- fromAmountForGas ↔ String?
-
getter/setter pair
- fromChainId ↔ String
-
getter/setter pair
- fromTokenAddress ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- options ↔ LifiRoutesRequestOptions?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toAddress ↔ String?
-
getter/setter pair
- toChainId ↔ String
-
getter/setter pair
- toTokenAddress ↔ String
-
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → LifiQuoteRequest