PortalBuildSolanaTransactionResponse class

Response from PortalHostApi.buildSolanaTransaction.

transaction is a base64-encoded serialized Solana transaction ready to be signed and submitted via sol_signAndSendTransaction. Mirrors BuildSolanaTransactionResponse from the iOS and Android SDKs.

Constructors

PortalBuildSolanaTransactionResponse({required String transaction, required PortalBuildTransactionMetadata metadata, String? error})

Properties

error String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata PortalBuildTransactionMetadata
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transaction String
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited