YieldXyzActionResponse class
Response from entering/exiting/managing yield
Constructors
-
YieldXyzActionResponse({required String id, required YieldXyzActionIntent intent, required String type, required String yieldId, required String address, String? amount, String? amountRaw, String? amountUsd, required List<
YieldXyzActionTransaction?> transactions, required YieldXyzActionExecutionPattern executionPattern, required String createdAt, String? completedAt, required YieldXyzActionStatus status})
Properties
- address ↔ String
-
getter/setter pair
- amount ↔ String?
-
getter/setter pair
- amountRaw ↔ String?
-
getter/setter pair
- amountUsd ↔ String?
-
getter/setter pair
- completedAt ↔ String?
-
getter/setter pair
- createdAt ↔ String
-
getter/setter pair
- executionPattern ↔ YieldXyzActionExecutionPattern
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String
-
getter/setter pair
- intent ↔ YieldXyzActionIntent
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ YieldXyzActionStatus
-
getter/setter pair
-
transactions
↔ List<
YieldXyzActionTransaction?> -
getter/setter pair
- type ↔ String
-
getter/setter pair
- yieldId ↔ String
-
getter/setter pair
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → YieldXyzActionResponse