ZeroXBalanceIssue class

0x token balance issue details.

Constructors

ZeroXBalanceIssue({required String token, required String actual, required String expected})

Properties

actual String
getter/setter pair
expected String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) ZeroXBalanceIssue