ZeroXBalanceIssue class
0x token balance issue details.
Constructors
- ZeroXBalanceIssue({required String token, required String actual, required String expected})
Properties
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → ZeroXBalanceIssue